@@ -5,7 +5,7 @@ base = 'https://app.ayrshare.com/api/'
 
 ERROR_MSG = {
     "status": "error",
-    "message": "Wrong parameters. Please check at https://docs.ayrshare.com/rest-api/endpoints",
+    "message": "Wrong parameters. Please verify at https://docs.ayrshare.com/rest-api/endpoints",
 }
 
 def doPost(type, data, headerData):
